#!/usr/bin/env python

# utils - Provides several helper functions
#
# Author: Kyle Nitzsche <kyle.nitzsche@canonical.com>
#
# Copyright (c) 20100 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys
import datetime
import urllib2
import time
import os
from ConfigParser import RawConfigParser

def get_settings():
    SETTINGS_FILE = os.path.join(os.getcwd(), "config", "settings.conf")
    if not os.path.exists(SETTINGS_FILE):
        print "Error. Can't open {0}. Stopping.".format(SETTINGS_FILE)
        sys.exit(1)

    config = RawConfigParser()
    config.read(SETTINGS_FILE)

    settings = dict()

    # Read all configuration items in the settings file. This allows
    # us dynamically adding new items and getting them read automatically
    config_items = config.items('defaults')
    config_items.extend(config.items('distros'))

    for config_item in config_items:
        settings[config_item[0]] = config_item[1]
    
    # Infer the distro release from its codename in the settings
    # and add it explicitly to the settings dictionary
    settings['distro_release'] = config.get('distros', settings['distro_codename'])

    return settings

def get_working_pot_templates(settings):
    templates = os.path.join(os.getcwd(), 'data', settings['distro_codename'] + "-templates.txt")
    if not os.path.exists(templates):
        print >>sys.stderr, "Error: " + template + " file does not exist. Stopping."
        sys.exit(1)
    return templates

if __name__ == "__main__":
    get_settings()
    sys.exit(0)